/* Schedwi
   Copyright (C) 2007-2015 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* net_module.h -- Manages module functions */

#ifndef _NET_MODULE_H
#define _NET_MODULE_H

#include <schedwi.h>

#include <net_utils_glob.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int (*net_module OF((const char *module_name)))
			OF((net_id *, char *, size_t));
extern void add_module OF((	const char *module_name,
				int (*module)(net_id *, char *, size_t)));
extern void destroy_modules OF(());

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* net_module.h */

/*-----------------============== End Of File ==============-----------------*/
